==> ukui-power-manager_2.0.0.orig.tar.gz: ukui-power-manager/ukui-power-manager-tray/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DeviceForm</name>
    <message>
        <location filename="deviceform.ui" line="20"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="deviceform.ui" line="32"/>
        <location filename="deviceform.ui" line="45"/>
        <location filename="deviceform.ui" line="58"/>
        <location filename="deviceform.ui" line="74"/>
        <location filename="deviceform.ui" line="87"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="device_form.cpp" line="43"/>
        <source>RemainTime</source>
        <translation type="unfinished">预计剩余时间</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <location filename="devicewidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="device_widget.cpp" line="56"/>
        <source>RemainTime</source>
        <translation>预计剩余时间</translation>
    </message>
</context>
<context>
    <name>EngineDevice</name>
    <message>
        <location filename="enginedevice.cpp" line="208"/>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="208"/>
        <source>no</source>
        <translation>不</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="243"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="243"/>
        <source>No</source>
        <translation>不</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="552"/>
        <source>Unknown time</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="558"/>
        <location filename="enginedevice.cpp" line="579"/>
        <source>minute</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="560"/>
        <location filename="enginedevice.cpp" line="581"/>
        <source>minutes</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="571"/>
        <location filename="enginedevice.cpp" line="583"/>
        <source>hour</source>
        <translation>小时</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="573"/>
        <location filename="enginedevice.cpp" line="585"/>
        <source>hours</source>
        <translation>小时</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="644"/>
        <source>fully charged</source>
        <translation>已充满</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="654"/>
        <source>discharging(%1%)</source>
        <translation>放电(%1%)</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="680"/>
        <source>charging(%1%)</source>
        <translation>充电(%1%)</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="867"/>
        <source>AC adapter</source>
        <translation>交流电源适配器</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="871"/>
        <source>Laptop battery</source>
        <translation>笔记本电池</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="875"/>
        <source>UPS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="879"/>
        <source>Monitor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="883"/>
        <source>Mouse</source>
        <translation>鼠标</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="887"/>
        <source>Keyboard</source>
        <translation>键盘</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="891"/>
        <source>PDA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="899"/>
        <source>Media player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="903"/>
        <source>Tablet</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="907"/>
        <source>Computer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="911"/>
        <source>unrecognised</source>
        <translation>未识别</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="1036"/>
        <source>charging</source>
        <translation>充电中</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="1039"/>
        <source>discharging</source>
        <translation>放电</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="1042"/>
        <source>empty</source>
        <translation>电量空</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="1045"/>
        <source>fully</source>
        <translation>电量满</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="1048"/>
        <source>other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="62"/>
        <source>SetPower</source>
        <translation>设置电源和睡眠</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="64"/>
        <source>ShowPercentage</source>
        <translation>显示百分比</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="66"/>
        <source>SetBrightness</source>
        <translation>调整亮度</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="98"/>
        <source>discharge notify notification</source>
        <translation>正在放电</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="99"/>
        <source>battery is discharging!</source>
        <translation>电池正在放电</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="118"/>
        <source>fullly charged notification</source>
        <translation>电池充满</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="119"/>
        <source>battery is fullly charged!</source>
        <translation>电池已经充满</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="138"/>
        <source>low battery notification</source>
        <translation>电量低</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="139"/>
        <source>battery is low,please plug in!</source>
        <translation>电量低，请充电</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="158"/>
        <source>critical battery notification</source>
        <translation>电量很低</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="159"/>
        <source>battery is critical low,please plug in!</source>
        <translation>电量很低，请充电</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="179"/>
        <source>very low battery notification</source>
        <translation>电量非常低</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="180"/>
        <source>battery is very low,please plug in!</source>
        <translation>电量即将耗尽！</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="278"/>
        <source>PowerManagement</source>
        <translation>电源管理</translation>
    </message>
    <message>
        <source>PowerSaveMode</source>
        <translation type="vanished">省电模式</translation>
    </message>
    <message>
        <source>BatterySave</source>
        <translation type="vanished">电池养护</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation type="vanished">亮度</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="enginedevice.cpp" line="583"/>
        <source></source>
        <comment>tablet device</comment>
        <translation></translation>
    </message>
</context>
</TS>

==> ukui-power-manager_2.0.2.orig.tar.gz: ukui-power-manager/ukui-power-manager-tray/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DeviceForm</name>
    <message>
        <location filename="deviceform.ui" line="32"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="deviceform.ui" line="44"/>
        <location filename="deviceform.ui" line="57"/>
        <location filename="deviceform.ui" line="70"/>
        <location filename="deviceform.ui" line="86"/>
        <location filename="deviceform.ui" line="99"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="device_form.cpp" line="107"/>
        <source>RemainTime</source>
        <translation>预计剩余时间</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <source>RemainTime</source>
        <translation type="vanished">预计剩余时间</translation>
    </message>
</context>
<context>
    <name>EngineDevice</name>
    <message>
        <location filename="enginedevice.cpp" line="243"/>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="243"/>
        <source>no</source>
        <translation>不</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="278"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="278"/>
        <source>No</source>
        <translation>不</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="600"/>
        <source>Unknown time</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="606"/>
        <location filename="enginedevice.cpp" line="627"/>
        <source>minute</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="608"/>
        <location filename="enginedevice.cpp" line="629"/>
        <source>minutes</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="619"/>
        <location filename="enginedevice.cpp" line="631"/>
        <source>hour</source>
        <translation>小时</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="621"/>
        <location filename="enginedevice.cpp" line="633"/>
        <source>hours</source>
        <translation>小时</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="686"/>
        <source>fully charged</source>
        <translation>已充满</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="705"/>
        <source>discharging(%1%)</source>
        <translation>放电(%1%)</translation>
    </message>
    <message>
        <source>charging(%1%)</source>
        <translation type="vanished">充电(%1%)</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="918"/>
        <source>AC adapter</source>
        <translation>交流电源适配器</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="922"/>
        <source>Laptop battery</source>
        <translation>笔记本电池</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="926"/>
        <source>UPS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="930"/>
        <source>Monitor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="934"/>
        <source>Mouse</source>
        <translation>鼠标</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="938"/>
        <source>Keyboard</source>
        <translation>键盘</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="942"/>
        <source>PDA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="950"/>
        <source>Media player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="954"/>
        <source>Tablet</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="958"/>
        <source>Computer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="962"/>
        <source>unrecognised</source>
        <translation>未识别</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="688"/>
        <location filename="enginedevice.cpp" line="710"/>
        <location filename="enginedevice.cpp" line="1086"/>
        <source>charging</source>
        <translation>正在充电</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="1089"/>
        <source>discharging</source>
        <translation>放电</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="1092"/>
        <source>empty</source>
        <translation>电量空</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="1095"/>
        <source>fully</source>
        <translation>电量满</translation>
    </message>
    <message>
        <location filename="enginedevice.cpp" line="1098"/>
        <source>other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="45"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="92"/>
        <source>PushButton</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="468"/>
        <source>SetPower</source>
        <translation>设置电源和睡眠</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="487"/>
        <source>ShowPercentage</source>
        <translation>显示百分比</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="507"/>
        <source>SetBrightness</source>
        <translation>调整亮度</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="85"/>
        <source>discharge notify notification</source>
        <translation>正在放电</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>battery is discharging!</source>
        <translation>电池正在放电</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="104"/>
        <source>fullly charged notification</source>
        <translation>电池充满</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="105"/>
        <source>battery is fullly charged!</source>
        <translation>电池已经充满</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="123"/>
        <source>low battery notification</source>
        <translation>电量低</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <source>battery is low,please plug in!</source>
        <translation>电量低，请充电</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="142"/>
        <source>critical battery notification</source>
        <translation>电量很低</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="143"/>
        <source>battery is critical low,please plug in!</source>
        <translation>电量很低，请充电</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="162"/>
        <source>very low battery notification</source>
        <translation>电量非常低</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="163"/>
        <source>battery is very low,please plug in!</source>
        <translation>电量即将耗尽！</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="435"/>
        <source>PowerManagement</source>
        <translation>电源管理</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="440"/>
        <source>Stats</source>
        <oldsource>Statistics</oldsource>
        <translation>电源统计</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="530"/>
        <source>PowerManager</source>
        <translation>电源管理</translation>
    </message>
    <message>
        <source>PowerStatistics</source>
        <translation type="vanished">电源统计</translation>
    </message>
    <message>
        <source>PowerSaveMode</source>
        <translation type="vanished">省电模式</translation>
    </message>
    <message>
        <source>BatterySave</source>
        <translation type="vanished">电池养护</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation type="vanished">亮度</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="enginedevice.cpp" line="583"/>
        <source></source>
        <comment>tablet device</comment>
        <translation></translation>
    </message>
</context>
</TS>
